﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfApplication2
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        ObservableCollection<Data> data;
        public MainWindow()
        {
            InitializeComponent();
            data = Data.GetData(10, 0, 10);
            this.DataContext = data;            
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            data.Clear();
            Random r = new Random();
            for (int i = 0; i < 10; i++)
            {
                data.Add(new Data
                {
                    Date = DateTime.Now.AddDays(i),
                    Label = "Item " + i,
                    Open = r.Next(0, 11),
                    Close = r.Next(0, 11),
                    High = r.Next(0, 11),
                    Low = r.Next(0, 11),
                    Value = i % 2 != 0,
                });
            }
        }
    }

    public class Data : INotifyPropertyChanged
    {
        private int open;
        private int close;
        private int high;
        private int low;
        private bool value;
        private string label;
        private DateTime date;


        public DateTime Date
        {
            get { return date; }
            set
            {
                date = value;
                PropChanged("Date");
            }
        }


        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int Open
        {
            get { return open; }
            set
            {
                open = value;
                PropChanged("Open");
            }
        }

        public int Close
        {
            get { return close; }
            set
            {
                close = value;
                PropChanged("Close");
            }
        }

        public int High
        {
            get { return high; }
            set
            {
                high = value;
                PropChanged("High");
            }
        }

        public int Low
        {
            get { return low; }
            set
            {
                low = value;
                PropChanged("Low");
            }
        }

        public bool Value
        {
            get { return value; }
            set
            {
                this.value = value;
                PropChanged("Value");
            }
        }

        public double Avarage
        {
            get
            {
                return (Open + Close + High + Low) / 4;
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Date = DateTime.Now.AddDays(i),
                    Label = "Item " + i,
                    Open = r.Next(rangeStart, rangeEnd),
                    Close = r.Next(rangeStart, rangeEnd),
                    High = r.Next(rangeStart, rangeEnd),
                    Low = r.Next(rangeStart, rangeEnd),
                    Value = i % 2 == 0,
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
}
